//Source file: ServiceKeyType.java
//Date: October 2006
//Service Broker Interfaces and Data Types for 3GPP TS 29.198-16 V2.0.0 Release 7

package org.csapi.jr.se.svcbroker;

/**
 * Defines the type of service key used.
 *
 */
public final class ServiceKeyType implements java.io.Serializable {

    private int _value;
    private static int _size = 2;
    private static ServiceKeyType[] _array = new ServiceKeyType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private ServiceKeyType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined
     */
    public static final int _SERVICE_KEY_UNDEFINED =  0;

    /**
     * Undefined
     */
    public static final ServiceKeyType SERVICE_KEY_UNDEFINED = new ServiceKeyType(_SERVICE_KEY_UNDEFINED);

    /**
     * 
     */
    public static final int _SERVICE_KEY =  1;

    /**
     * 
     */
    public static final ServiceKeyType SERVICE_KEY = new ServiceKeyType(_SERVICE_KEY);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved ServiceKeyType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the ServiceKeyType object
     */
    public String getValueText() {
        switch (_value) {
            case _SERVICE_KEY_UNDEFINED:
                return "SERVICE_KEY_UNDEFINED";
            case _SERVICE_KEY:
                return "SERVICE_KEY";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 1
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static ServiceKeyType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof ServiceKeyType)) {
            return false;
        }
        ServiceKeyType serviceKeyType = (ServiceKeyType) o; 
        if(!(this.getValue() == serviceKeyType.getValue())) {
            return false;
        }
        if (this.hashCode() != serviceKeyType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // ServiceKeyType

